@@ -24,9 +24,6 @@ use strict;
 use warnings;
 use re 'taint';
 
-require 5.008;     # need basic Unicode support for HTML::Parser::utf8_mode
-# require 5.008008;  # Bug 3787; [perl #37950]: Malformed UTF-8 character ...
-
 use HTML::Parser 3.43 ();
 use Mail::SpamAssassin::Logger;
 use Mail::SpamAssassin::Constants qw(:sa);
@@ -66,7 +63,7 @@ my %elements_whitespace = map {; $_ => 1 }
 
 # elements that push URIs
 my %elements_uri = map {; $_ => 1 }
-  qw( body table tr td a area link img frame iframe embed script form base bgsound ),
+  qw( body table tr td a area link img frame iframe embed script form base bgsound meta ),
 ;
 
 # style attribute not accepted
@@ -248,6 +245,18 @@ sub parse {
   # the HTML::Parser API won't do it for us
   $text =~ s/<(\w+)\s*\/>/<$1>/gi;
 
+  # Normalize unicode quotes, messes up attributes parsing
+  # U+201C e2 80 9c LEFT DOUBLE QUOTATION MARK
+  # U+201D e2 80 9d RIGHT DOUBLE QUOTATION MARK
+  # Examples of input:
+  # <a href=\x{E2}\x{80}\x{9D}https://foobar.com\x{E2}\x{80}\x{9D}>
+  # .. results in uri "\x{E2}\x{80}\x{9D}https://foobar.com\x{E2}\x{80}\x{9D}"
+  if (utf8::is_utf8($text)) {
+    $text =~ s/(?:\x{201C}|\x{201D})/"/g;
+  } else {
+    $text =~ s/\x{E2}\x{80}(?:\x{9C}|\x{9D})/"/g;
+  }
+
   if (!$self->UNIVERSAL::can('utf8_mode')) {
     # utf8_mode is cleared by default, only warn if it would need to be set
     warn "message: cannot set utf8_mode, module HTML::Parser is too old\n"
@@ -340,20 +349,25 @@ sub push_uri {
   my ($self, $type, $uri) = @_;
 
   $uri = $self->canon_uri($uri);
+  return if $uri eq '';
   utf8::encode($uri) if $self->{SA_encode_results};
 
-  my $target = target_uri($self->{base_href} || "", $uri);
-
-  # skip things like <iframe src="" ...>
-  $self->{uri}->{$uri}->{types}->{$type} = 1  if $uri ne '';
+  if ($uri =~ /^(?:data|mailto|file|cid|tel):/i) {
+    # No target handling required
+    $self->{uri}->{$uri}->{types}->{$type} = 1;
+  } else {
+    my $target = target_uri($self->{base_href} || "", $uri);
+    # skip things like <iframe src="" ...>
+    $self->{uri}->{$target}->{types}->{$type} = 1  if $target ne '';
+  }
 }
 
 sub canon_uri {
   my ($self, $uri) = @_;
 
   # URIs don't have leading/trailing whitespace ...
-  $uri =~ s/^\s+//;
-  $uri =~ s/\s+$//;
+  $uri =~ s/^[\s\xA0]+//;
+  $uri =~ s/[\s\xA0]+$//;
 
   # Make sure all the URIs are nice and short
   if (length $uri > MAX_URI_LENGTH) {
@@ -374,7 +388,20 @@ sub html_uri {
     }
   }
   elsif ($tag =~ /^(?:a|area|link)$/) {
+    while ( my ( $k, $v ) = each %$attr ) {
+      # read uris from bad formatted html as well
+      if($k =~ /\w{1,8}\/href/) {
+        delete($attr->{$k});
+        $attr->{href} = $v;
+      }
+    }
     if (defined $attr->{href}) {
+      # Remove the Unicode "replacement character" from the url
+      if (utf8::is_utf8($attr->{href})) {
+        $attr->{href} =~ s/\x{FEFF}//g;
+      } else {
+        $attr->{href} =~ s/\x{EF}\x{BB}\x{BF}//g;
+      }
       $self->push_uri($tag, $attr->{href});
     }
     if (defined $attr->{'data-saferedirecturl'}) {
@@ -382,6 +409,13 @@ sub html_uri {
     }
   }
   elsif ($tag =~ /^(?:img|frame|iframe|embed|script|bgsound)$/) {
+    while ( my ( $k, $v ) = each %$attr ) {
+      # read uris from bad formatted html as well
+      if($k =~ /\w{1,8}\/src/) {
+        delete($attr->{$k});
+        $attr->{src} = $v;
+      }
+    }
     if (defined $attr->{src}) {
       $self->push_uri($tag, $attr->{src});
     }
@@ -414,6 +448,17 @@ sub html_uri {
       }
     }
   }
+  elsif ($tag eq "meta" &&
+    exists $attr->{'http-equiv'} &&
+    exists $attr->{content} &&
+    $attr->{'http-equiv'} =~ /refresh/i &&
+    $attr->{content} =~ /\burl\s*=/i)
+  {
+      my $uri = $attr->{content};
+      $uri =~ s/^.*\burl\s*=\s*//i;
+      $uri =~ s/\s*;.*//i;
+      $self->push_uri($tag, $uri);
+  }
 }
 
 # this might not be quite right, may need to pay attention to table nesting
@@ -515,8 +560,11 @@ sub text_style {
 	  if (/^\s*(background-)?color:\s*(.+?)\s*$/i) {
 	    my $whcolor = $1 ? 'bgcolor' : 'fgcolor';
 	    my $value = lc $2;
+	    # prevent parsing of the valid CSS3 property value as
+	    # 'invalid color' (Bug 7892)
+	    $value =~ s/\s*!\s*important$//;
 
-	    if ($value =~ /rgb/) {
+	    if (index($value, 'rgb') >= 0) {
 	      $value =~ tr/0-9,//cd;
 	      my @rgb = split(/,/, $value);
               $new{$whcolor} = sprintf("#%02x%02x%02x",
@@ -527,15 +575,41 @@ sub text_style {
               # do nothing, just prevent parsing of the valid
               # CSS3 property value as 'invalid color' (Bug 7778)
             }
+            elsif ($value eq 'transparent') {
+              # keep for now, handle outside the loop (Bug 8205)
+              $new{$whcolor} = $value;
+            }
 	    else {
 	      $new{$whcolor} = name_to_rgb($value);
 	    }
 	  }
+          elsif (/^\s*background:\s*(.+?)\s*$/) {
+            # parse CSS background property (Bug 8210)
+            my $layers = parse_css_background(lc($1));
+            # loop through values in the bottom layer and look for valid colors
+            for my $value (@{$layers->[-1]}) {
+              my $color = name_to_rgb($value);
+              if ($color ne 'invalid') {
+                $new{bgcolor} = $color;
+                last;
+              }
+            }
+
+	  }
 	  elsif (/^\s*([a-z_-]+)\s*:\s*(\S.*?)\s*$/i) {
 	    # "display: none", "visibility: hidden", etc.
 	    $new{'style_'.$1} = $2;
 	  }
 	}
+        # Handle transparent colors (Bug 8205)
+        if ($new{bgcolor} eq 'transparent') {
+          # replace with parent's bgcolor
+          $new{bgcolor} = $self->{text_style}[-1]->{bgcolor};
+        }
+        if ($new{fgcolor} eq 'transparent') {
+          # replace with current bgcolor
+          $new{fgcolor} = $new{bgcolor};
+        }
       }
       elsif ($name eq "bgcolor") {
 	# overwrite with hex value, $new{bgcolor} is set below
@@ -564,6 +638,92 @@ sub text_style {
   }
 }
 
+# Parses a CSS background property value.
+# Returns an arrayref of layers, each layer is an arrayref of values such as
+# [
+#   'rgb(255, 192, 0)',
+#   '35%',
+#   'url("../../media/examples/lizard.png")'
+# ]
+# https://developer.mozilla.org/en-US/docs/Web/CSS/background
+sub parse_css_background {
+  my ($background) = @_;
+
+  my @layers;
+  my @tokens;
+  my @stack;
+  my ($state,$token) = (0,'');
+  for (my $i=0;$i < length($background);$i++) {
+    my $ch = substr($background, $i, 1);
+    if ($state == 0) {
+      if ($ch eq ' ') {
+        push @tokens, $token if $token ne '';
+        $token = '';
+      } elsif ($ch eq '(') {
+        $token .= $ch;
+        push @stack, $state;
+        $state = 1;
+      } elsif ($ch eq '"') {
+        $token .= $ch;
+        push @stack, $state;
+        $state = 2;
+      } elsif ($ch eq q(')) {
+        $token .= $ch;
+        push @stack, $state;
+        $state = 3;
+      } elsif ($ch eq ',') {
+        push @tokens, $token if $token ne '';
+        $token = '';
+        push @layers, [ @tokens ];
+        @tokens = ();
+      } else {
+        $token .= $ch;
+      }
+    } elsif ($state == 1) {
+      if ($ch eq ')') {
+        $token .= $ch;
+        push @tokens, $token;
+        $token = '';
+        $state = pop @stack;
+      } elsif ($ch eq '"') {
+        $token .= $ch;
+        push(@stack, $state);
+        $state = 2;
+      } elsif ($ch eq q(')) {
+        $token .= $ch;
+        push(@stack, $state);
+        $state = 3;
+      } else {
+        $token .= $ch;
+      }
+    } elsif ($state == 2) {
+      if ($ch eq '"') {
+        $token .= $ch;
+        $state = pop @stack;
+      } else {
+        $token .= $ch;
+      }
+    } elsif ($state == 3) {
+      if ($ch eq q(')) {
+        $token .= $ch;
+        $state = pop @stack;
+      } else {
+        $token .= $ch;
+      }
+    }
+  }
+
+  if ($token ne '') {
+    push @tokens, $token;
+  }
+  if ( scalar @tokens > 0 ) {
+    push @layers, [ @tokens ];
+  }
+
+  return \@layers;
+
+}
+
 sub html_font_invisible {
   my ($self, $text) = @_;
 
@@ -701,6 +861,8 @@ sub html_tests {
   {
     $self->{charsets} .= exists $self->{charsets} ? " $1" : $1;
   }
+
+  # todo: capture URI from meta refresh tag
 }
 
 sub display_text {
@@ -1150,7 +1312,7 @@ sub _merge_uri {
     return "/" . $r_path;
   }
   else {
-    if ($base_path =~ m|/|) {
+    if (index($base_path, '/') >= 0) {
       $base_path =~ s|(?<=/)[^/]*$||;
     }
     else {
@@ -1229,7 +1391,7 @@ sub target_uri {
       $result .= "ftp:";
     }
   }
-  if ($t{authority}) {
+  if (defined $t{authority}) {
     $result .= "//" . $t{authority};
   }
   $result .= $t{path};
